"""World Of Games

Play some little games, have fun :)
You can execute the game by call package name.

To run the game, write:
MainGame.start_game()
after you imported the package.
"""
from wog import MainGame
